.. CrunchyFrog API documentation master file, created by sphinx-quickstart on Wed Dec  3 06:23:52 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to CrunchyFrog API's documentation!
===========================================

Contents:

.. toctree::
   :maxdepth: 2

   cfpackage
   instances
   application
   configuration
   datasources
   widgets
   plugins
   misc
   api/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

